Pointer

Trait Pointer 

pub trait Pointer<T: ?Sized + Pointable> {
    // Required methods
    fn into_usize(self) -> usize;
    unsafe fn from_usize(data: usize) -> Self;
}
A trait for either Owned or Shared pointers.

Required Methods

fn into_usize(self) -> usize

Returns the machine representation of the pointer.

unsafe fn from_usize(data: usize) -> Self

Returns a new pointer pointing to the tagged pointer data.

Safety

The given data should have been created by Pointer::into_usize(), and one data should not be converted back by Pointer::from_usize() multiple times.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T: ?Sized + Pointable> Pointer<T> for Owned<T>

Source

impl<T: ?Sized + Pointable> Pointer<T> for Shared<'_, T>